@@ -196,12 +196,13 @@ func RunWithSuggestedFixes(t Testing, dir string, a *analysis.Analyzer, patterns
 							want := string(bytes.TrimRight(vf.Data, "\n")) + "\n"
 							formatted, err := format.Source([]byte(out))
 							if err != nil {
+								t.Errorf("%s: error formatting edited source: %v\n%s", file.Name(), err, out)
 								continue
 							}
 							if want != string(formatted) {
 								d, err := myers.ComputeEdits("", want, string(formatted))
 								if err != nil {
-									t.Errorf("failed to compute suggested fixes: %v", err)
+									t.Errorf("failed to compute suggested fix diff: %v", err)
 								}
 								t.Errorf("suggested fixes failed for %s:\n%s", file.Name(), diff.ToUnified(fmt.Sprintf("%s.golden [%s]", file.Name(), sf), "actual", want, d))
 							}
@@ -225,12 +226,13 @@ func RunWithSuggestedFixes(t Testing, dir string, a *analysis.Analyzer, patterns
 
 				formatted, err := format.Source([]byte(out))
 				if err != nil {
+					t.Errorf("%s: error formatting resulting source: %v\n%s", file.Name(), err, out)
 					continue
 				}
 				if want != string(formatted) {
 					d, err := myers.ComputeEdits("", want, string(formatted))
 					if err != nil {
-						t.Errorf("failed to compute edits: %s", err)
+						t.Errorf("%s: failed to compute suggested fix diff: %s", file.Name(), err)
 					}
 					t.Errorf("suggested fixes failed for %s:\n%s", file.Name(), diff.ToUnified(file.Name()+".golden", "actual", want, d))
 				}
